@@ -34,9 +34,9 @@ class MulticollinearityDataCheck(DataCheck):
 
             Columns in X that are highly correlated with each other will be identified using mutual information.
 
-            >>> col = pd.Series([1, 0, 2, 3, 4])
+            >>> col = pd.Series([1, 0, 2, 3, 4] * 15)
             >>> X = pd.DataFrame({"col_1": col, "col_2": col * 3})
-            >>> y = pd.Series([1, 0, 0, 1, 0])
+            >>> y = pd.Series([1, 0, 0, 1, 0] * 15)
             ...
             >>> multicollinearity_check = MulticollinearityDataCheck(threshold=1.0)
             >>> assert multicollinearity_check.validate(X, y) == [
