@@ -1,3 +1,4 @@
+"""Lead scoring objective."""
 import math
 
 from .binary_classification_objective import BinaryClassificationObjective
@@ -6,7 +7,7 @@ from .binary_classification_objective import BinaryClassificationObjective
 class LeadScoring(BinaryClassificationObjective):
     """Lead scoring.
 
-    Arguments:
+    Args:
         true_positives (int): Reward for a true positive. Defaults to 1.
         false_positives (int): Cost for a false positive. Should be negative. Defaults to -1.
     """
@@ -25,7 +26,7 @@ class LeadScoring(BinaryClassificationObjective):
     def objective_function(self, y_true, y_predicted, X=None, sample_weight=None):
         """Calculate the profit per lead.
 
-        Arguments:
+        Args:
             y_predicted (pd.Series): Predicted labels
             y_true (pd.Series): True labels
             X (pd.DataFrame): Ignored.
