@@ -12,6 +12,8 @@ from evalml.exceptions.exceptions import (
     MethodPropertyNotFoundError,
     MissingComponentError,
     ParameterNotUsedWarning,
+    PipelineError,
+    PipelineErrorCodeEnum,
 )
 from evalml.pipelines.components import ComponentBase, Estimator, Transformer
 from evalml.pipelines.components.utils import handle_component_class
@@ -54,8 +56,10 @@ class ComponentGraph:
         >>> assert component_graph.default_parameters == {
         ...     'Imputer': {'categorical_impute_strategy': 'most_frequent',
         ...                 'numeric_impute_strategy': 'mean',
+        ...                 'boolean_impute_strategy': 'most_frequent',
         ...                 'categorical_fill_value': None,
-        ...                 'numeric_fill_value': None},
+        ...                 'numeric_fill_value': None,
+        ...                 'boolean_fill_value': None},
         ...     'One Hot Encoder': {'top_n': 10,
         ...                         'features_to_encode': None,
         ...                         'categories': None,
@@ -397,6 +401,9 @@ class ComponentGraph:
 
         Returns:
             dict: Outputs from each component.
+
+        Raises:
+            PipelineError: if input data types are different from the input types the pipeline was fitted on
         """
         X = infer_feature_types(X)
         if not fit:
@@ -406,8 +413,13 @@ class ComponentGraph:
                 else X.ww.schema
             )
             if not _schema_is_equal(X_schema, self._input_types):
-                raise ValueError(
-                    "Input X data types are different from the input types the pipeline was fitted on."
+                raise PipelineError(
+                    "Input X data types are different from the input types the pipeline was fitted on.",
+                    code=PipelineErrorCodeEnum.PREDICT_INPUT_SCHEMA_UNEQUAL,
+                    details={
+                        "input_features_types": X_schema.types,
+                        "pipeline_features_types": self._input_types.types,
+                    },
                 )
         else:
             self._input_types = (
@@ -675,19 +687,27 @@ class ComponentGraph:
 
         Returns:
             dict: Dictionary of all component parameters if return_dict is True, else None
+
+        Raises:
+            ValueError: If the componentgraph is not instantiated
         """
         logger = get_logger(f"{__name__}.describe")
         components = {}
         for number, component in enumerate(self.component_instances.values(), 1):
             component_string = str(number) + ". " + component.name
             logger.info(component_string)
-            components.update(
-                {
-                    component.name: component.describe(
-                        print_name=False, return_dict=return_dict
-                    )
-                }
-            )
+            try:
+                components.update(
+                    {
+                        component.name: component.describe(
+                            print_name=False, return_dict=return_dict
+                        )
+                    }
+                )
+            except TypeError:
+                raise ValueError(
+                    "You need to instantiate ComponentGraph before calling describe()"
+                )
         if return_dict:
             return components
 
