@@ -3,7 +3,11 @@ from evalml.model_family import ModelFamily
 from evalml.pipelines.components import Estimator
 from evalml.utils import classproperty
 
-_nonstackable_model_families = [ModelFamily.BASELINE, ModelFamily.NONE]
+_nonstackable_model_families = [
+    ModelFamily.BASELINE,
+    ModelFamily.VOWPAL_WABBIT,
+    ModelFamily.NONE,
+]
 
 
 class StackedEnsembleBase(Estimator):
