@@ -90,12 +90,6 @@ class XGBoostClassifier(Estimator):
             parameters=parameters, component_obj=xgb_classifier, random_seed=random_seed
         )
 
-    @staticmethod
-    def _convert_bool_to_int(X):
-        return {
-            col: "Integer" for col in X.ww.select("boolean", return_schema=True).columns
-        }
-
     def _label_encode(self, y):
         if not is_integer_dtype(y):
             self._label_encoder = LabelEncoder()
@@ -113,9 +107,8 @@ class XGBoostClassifier(Estimator):
             self
         """
         X, y = super()._manage_woodwork(X, y)
-        X.ww.set_types(self._convert_bool_to_int(X))
         self.input_feature_names = list(X.columns)
-        X = _rename_column_names_to_numeric(X, flatten_tuples=False)
+        X = _rename_column_names_to_numeric(X)
         y = self._label_encode(y)
         self._component_obj.fit(X, y)
         return self
@@ -130,8 +123,7 @@ class XGBoostClassifier(Estimator):
             pd.DataFrame: Predicted values.
         """
         X, _ = super()._manage_woodwork(X)
-        X.ww.set_types(self._convert_bool_to_int(X))
-        X = _rename_column_names_to_numeric(X, flatten_tuples=False)
+        X = _rename_column_names_to_numeric(X)
         predictions = super().predict(X)
         if not self._label_encoder:
             return predictions
@@ -150,8 +142,7 @@ class XGBoostClassifier(Estimator):
             pd.DataFrame: Predicted values.
         """
         X, _ = super()._manage_woodwork(X)
-        X.ww.set_types(self._convert_bool_to_int(X))
-        X = _rename_column_names_to_numeric(X, flatten_tuples=False)
+        X = _rename_column_names_to_numeric(X)
         return super().predict_proba(X)
 
     @property
