@@ -268,7 +268,6 @@ def test_get_best_sampler_for_data_auto(
     categorical_columns,
     size,
     mock_imbalanced_data_X_y,
-    has_minimal_dependencies,
 ):
     X, y = mock_imbalanced_data_X_y(problem_type, categorical_columns, size)
     name_output = get_best_sampler_for_data(X, y, "auto", sampler_balanced_ratio)
@@ -276,7 +275,7 @@ def test_get_best_sampler_for_data_auto(
         # the imbalanced data we get has a class ratio of 0.2 minority:majority
         assert name_output is None
     else:
-        if size == "large" or has_minimal_dependencies:
+        if size == "large":
             assert name_output == "Undersampler"
         else:
             assert name_output == "Oversampler"
@@ -288,17 +287,15 @@ def test_get_best_sampler_for_data_sampler_method(
     categorical_columns,
     sampler_method,
     mock_imbalanced_data_X_y,
-    has_minimal_dependencies,
 ):
     X, y = mock_imbalanced_data_X_y("binary", categorical_columns, "large")
     name_output = get_best_sampler_for_data(X, y, sampler_method, 0.5)
-    if sampler_method == "Undersampler" or has_minimal_dependencies:
+    if sampler_method == "Undersampler":
         assert name_output == "Undersampler"
     else:
         assert name_output == "Oversampler"
 
 
-@pytest.mark.noncore_dependency
 def test_get_best_sampler_for_data_nonnumeric_noncategorical_columns(X_y_binary):
     X, y = X_y_binary
     X = pd.DataFrame(X)
