@@ -1,13 +1,10 @@
 import warnings
 
 import pandas as pd
-import pytest
 
 from evalml.pipelines.components import CatBoostRegressor
 from evalml.utils import SEED_BOUNDS
 
-pytestmark = pytest.mark.noncore_dependency
-
 
 def test_catboost_regressor_random_seed_bounds_seed(X_y_regression):
     """ensure catboost's RNG doesn't fail for the min/max bounds we support on user-inputted random seeds"""
