@@ -1,5 +1,6 @@
 from datetime import datetime
 
+import numpy as np
 import pandas as pd
 import pytest
 import woodwork as ww
@@ -46,27 +47,27 @@ def test_target_leakage_data_check_init():
 
 
 def test_target_leakage_data_check_warnings():
-    y = pd.Series([1, 0, 1, 1])
+    y = pd.Series(range(30))
     X = pd.DataFrame()
     X["a"] = y * 3
     X["b"] = y - 1
     X["c"] = y / 10
-    X["d"] = ~y
-    X["e"] = [0, 0, 0, 0]
-    y = y.astype(bool)
+    X["d"] = y % 2
+    X["e"] = [0] * 30
+    X.ww.init(logical_types={"d": "Boolean"})
 
     leakage_check = TargetLeakageDataCheck(pct_corr_threshold=0.5)
     assert leakage_check.validate(X, y) == [
         DataCheckWarning(
-            message="Columns 'a', 'b', 'c', 'd' are 50.0% or more correlated with the target",
+            message="Columns 'a', 'b', 'c' are 50.0% or more correlated with the target",
             data_check_name=target_leakage_data_check_name,
             message_code=DataCheckMessageCode.TARGET_LEAKAGE,
-            details={"columns": ["a", "b", "c", "d"]},
+            details={"columns": ["a", "b", "c"]},
             action_options=[
                 DataCheckActionOption(
                     DataCheckActionCode.DROP_COL,
                     data_check_name=target_leakage_data_check_name,
-                    metadata={"columns": ["a", "b", "c", "d"]},
+                    metadata={"columns": ["a", "b", "c"]},
                 )
             ],
         ).to_dict(),
@@ -74,11 +75,10 @@ def test_target_leakage_data_check_warnings():
 
 
 def test_target_leakage_data_check_singular_warning():
-    y = pd.Series([1, 0, 1, 1])
+    y = pd.Series(range(30))
     X = pd.DataFrame()
     X["a"] = y * 3
-    X["b"] = [0, 0, 0, 0]
-    y = y.astype(bool)
+    X["b"] = [0] * 30
 
     leakage_check = TargetLeakageDataCheck(pct_corr_threshold=0.5)
     assert leakage_check.validate(X, y) == [
@@ -108,26 +108,26 @@ def test_target_leakage_data_check_empty(data_type, make_data_type):
 
 def test_target_leakage_data_check_input_formats():
     leakage_check = TargetLeakageDataCheck(pct_corr_threshold=0.8)
-    y = pd.Series([1, 0, 1, 1])
+    y = pd.Series(range(30))
     X = pd.DataFrame()
     X["a"] = y * 3
     X["b"] = y - 1
     X["c"] = y / 10
-    X["d"] = ~y
-    X["e"] = [0, 0, 0, 0]
-    y = y.astype(bool)
+    X["d"] = y % 2
+    X["e"] = [0] * 30
+    X.ww.init(logical_types={"d": "Boolean"})
 
     expected = [
         DataCheckWarning(
-            message="Columns 'a', 'b', 'c', 'd' are 80.0% or more correlated with the target",
+            message="Columns 'a', 'b', 'c' are 80.0% or more correlated with the target",
             data_check_name=target_leakage_data_check_name,
             message_code=DataCheckMessageCode.TARGET_LEAKAGE,
-            details={"columns": ["a", "b", "c", "d"]},
+            details={"columns": ["a", "b", "c"]},
             action_options=[
                 DataCheckActionOption(
                     DataCheckActionCode.DROP_COL,
                     data_check_name=target_leakage_data_check_name,
-                    metadata={"columns": ["a", "b", "c", "d"]},
+                    metadata={"columns": ["a", "b", "c"]},
                 ),
             ],
         ).to_dict(),
@@ -144,15 +144,15 @@ def test_target_leakage_data_check_input_formats():
     # test X as np.array
     assert leakage_check.validate(X.to_numpy().astype(float), y) == [
         DataCheckWarning(
-            message="Columns '0', '1', '2', '3' are 80.0% or more correlated with the target",
+            message="Columns '0', '1', '2' are 80.0% or more correlated with the target",
             data_check_name=target_leakage_data_check_name,
             message_code=DataCheckMessageCode.TARGET_LEAKAGE,
-            details={"columns": [0, 1, 2, 3]},
+            details={"columns": [0, 1, 2]},
             action_options=[
                 DataCheckActionOption(
                     DataCheckActionCode.DROP_COL,
                     data_check_name=target_leakage_data_check_name,
-                    metadata={"columns": [0, 1, 2, 3]},
+                    metadata={"columns": [0, 1, 2]},
                 )
             ],
         ).to_dict(),
@@ -173,32 +173,33 @@ def test_target_leakage_none():
 def test_target_leakage_types():
     leakage_check = TargetLeakageDataCheck(pct_corr_threshold=0.8)
 
-    y = pd.Series([1, 0, 1, 1])
+    y = pd.Series([1, 0, 1, 1] * 6 + [1])
     X = pd.DataFrame()
-    X["a"] = ["a", "b", "a", "a"]
-    X["b"] = y - 1
+    X["a"] = ["a", "b", "a", "a"] * 6 + ["a"]
+    X["b"] = y
+
     X["c"] = [
         datetime.strptime("2015", "%Y"),
         datetime.strptime("2016", "%Y"),
         datetime.strptime("2015", "%Y"),
         datetime.strptime("2015", "%Y"),
-    ]
+    ] * 6 + [datetime.strptime("2015", "%Y")]
     X["d"] = ~y
-    X["e"] = [0, 0, 0, 0]
+    X["e"] = np.zeros(len(y))
     y = y.astype(bool)
-    X.ww.init(logical_types={"a": "categorical"})
+    X.ww.init(logical_types={"a": "categorical", "d": "Boolean", "b": "Boolean"})
 
     expected = [
         DataCheckWarning(
-            message="Columns 'a', 'b', 'c', 'd' are 80.0% or more correlated with the target",
+            message="Columns 'a', 'b' are 80.0% or more correlated with the target",
             data_check_name=target_leakage_data_check_name,
             message_code=DataCheckMessageCode.TARGET_LEAKAGE,
-            details={"columns": ["a", "b", "c", "d"]},
+            details={"columns": ["a", "b"]},
             action_options=[
                 DataCheckActionOption(
                     DataCheckActionCode.DROP_COL,
                     data_check_name=target_leakage_data_check_name,
-                    metadata={"columns": ["a", "b", "c", "d"]},
+                    metadata={"columns": ["a", "b"]},
                 )
             ],
         ).to_dict(),
@@ -213,13 +214,41 @@ def test_target_leakage_multi():
     # test empty pd.DataFrame, empty pd.Series
     assert leakage_check.validate(pd.DataFrame(), pd.Series()) == []
 
-    y = pd.Series([1, 0, 2, 1, 2, 0])
+    y = pd.Series(
+        [1, 0, 2, 1, 2, 0, 1, 0, 2, 1, 2, 0, 1, 0, 2, 1, 2, 0, 1, 0, 2, 1, 2, 0, 1]
+    )
     X = pd.DataFrame()
     X["a"] = y * 3
     X["b"] = y - 1
     X["c"] = y / 10
-    X["d"] = [0, 0, 0, 0, 0, 0]
-    X["e"] = ["a", "b", "c", "a", "b", "c"]
+    X["d"] = np.zeros(len(y))
+    X["e"] = [
+        "a",
+        "b",
+        "c",
+        "a",
+        "b",
+        "c",
+        "a",
+        "b",
+        "c",
+        "a",
+        "b",
+        "c",
+        "a",
+        "b",
+        "c",
+        "a",
+        "b",
+        "c",
+        "a",
+        "b",
+        "c",
+        "a",
+        "b",
+        "c",
+        "a",
+    ]
 
     expected = [
         DataCheckWarning(
@@ -239,8 +268,8 @@ def test_target_leakage_multi():
 
     # test X, y with ww
     X_ww = X.copy()
-    X_ww.ww.init()
-    y_ww = ww.init_series(y)
+    X_ww.ww.init()  # logical_types={"b": "Categorical", "c": "Categorical"})
+    y_ww = ww.init_series(y)  # , logical_type="Categorical")
     assert leakage_check.validate(X_ww, y_ww) == expected
 
     #  test y as list
@@ -254,37 +283,61 @@ def test_target_leakage_regression():
     assert leakage_check.validate(pd.DataFrame(), pd.Series()) == []
 
     y = pd.Series(
-        [0.4, 0.1, 2.3, 4.3, 2.2, 1.8, 3.7, 3.6, 2.4, 0.9, 3.1, 2.8, 4.1, 1.6, 1.2]
+        [
+            0.7,
+            0.8,
+            1.6,
+            2.8,
+            4.0,
+            5.1,
+            5.2,
+            5.9,
+            6.1,
+            6.4,
+            8.7,
+            9.5,
+            13.2,
+            13.7,
+            14.8,
+            15.2,
+            15.8,
+            19.0,
+            19.2,
+            19.6,
+            20.0,
+            20.6,
+            21.1,
+            23.3,
+            25.3,
+            25.8,
+        ]
     )
     X = pd.DataFrame()
     X["a"] = y * 3
     X["b"] = y - 1
     X["c"] = y / 10
-    X["d"] = [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]
-    X["e"] = ["a", "b", "c", "d", "e", "f", "g", "h", "i", "j", "k", "l", "m", "n", "o"]
-    X.ww.init(logical_types={"e": "categorical"})
+    X["d"] = np.zeros(len(y))
+    X.ww.init()
 
     expected = [
         DataCheckWarning(
-            message="Columns 'a', 'b', 'c', 'e' are 80.0% or more correlated with the target",
+            message="Columns 'a', 'b', 'c' are 80.0% or more correlated with the target",
             data_check_name=target_leakage_data_check_name,
             message_code=DataCheckMessageCode.TARGET_LEAKAGE,
-            details={"columns": ["a", "b", "c", "e"]},
+            details={"columns": ["a", "b", "c"]},
             action_options=[
                 DataCheckActionOption(
                     DataCheckActionCode.DROP_COL,
                     data_check_name=target_leakage_data_check_name,
-                    metadata={"columns": ["a", "b", "c", "e"]},
+                    metadata={"columns": ["a", "b", "c"]},
                 )
             ],
         ).to_dict(),
     ]
 
     # test X, y with ww
-    X_ww = X.copy()
-    X_ww.ww.init()
     y_ww = ww.init_series(y)
-    assert leakage_check.validate(X_ww, y_ww) == expected
+    assert leakage_check.validate(X, y_ww) == expected
 
     #  test y as list
     assert leakage_check.validate(X, y.values) == expected
@@ -392,8 +445,8 @@ def test_target_leakage_none_pearson():
 
 
 def test_target_leakage_maintains_logical_types():
-    X = pd.DataFrame({"A": pd.Series([1, 2, 3]), "B": pd.Series([4, 5, 6])})
-    y = pd.Series([1, 2, 3])
+    X = pd.DataFrame({"A": pd.Series(range(1, 26)), "B": pd.Series(range(26, 51))})
+    y = pd.Series(range(1, 26))
 
     X.ww.init(logical_types={"A": "Unknown", "B": "Double"})
     messages = TargetLeakageDataCheck().validate(X, y)
