@@ -1221,10 +1221,8 @@ pipeline_test_cases = [
     product(pipeline_test_cases, algorithms),
 )
 def test_categories_aggregated_linear_pipeline(
-    pipeline_class_and_estimator, algorithm, fraud_100, has_minimal_dependencies
+    pipeline_class_and_estimator, algorithm, fraud_100
 ):
-    if has_minimal_dependencies and algorithm == "lime":
-        pytest.skip("Skipping because lime is a non-core dependency")
     X, y = fraud_100
     pipeline_class, estimator = pipeline_class_and_estimator
 
@@ -1273,12 +1271,7 @@ def test_categories_aggregated_linear_pipeline(
     "pipeline_class_and_estimator,algorithm",
     product(pipeline_test_cases, algorithms),
 )
-def test_categories_aggregated_text(
-    pipeline_class_and_estimator, algorithm, fraud_100, has_minimal_dependencies
-):
-    if has_minimal_dependencies and algorithm == "lime":
-        pytest.skip("Skipping because lime is a non-core dependency")
-
+def test_categories_aggregated_text(pipeline_class_and_estimator, algorithm, fraud_100):
     X, y = fraud_100
     pipeline_class, estimator = pipeline_class_and_estimator
 
@@ -1351,10 +1344,8 @@ def test_categories_aggregated_text(
     product(pipeline_test_cases, algorithms),
 )
 def test_categories_aggregated_date_ohe(
-    pipeline_class_and_estimator, algorithm, fraud_100, has_minimal_dependencies
+    pipeline_class_and_estimator, algorithm, fraud_100
 ):
-    if has_minimal_dependencies and algorithm == "lime":
-        pytest.skip("Skipping because lime is a non-core dependency")
     X, y = fraud_100
     pipeline_class, estimator = pipeline_class_and_estimator
 
@@ -1419,11 +1410,8 @@ def test_categories_aggregated_date_ohe(
     product(pipeline_test_cases, algorithms),
 )
 def test_categories_aggregated_pca_dag(
-    pipeline_class_and_estimator, algorithm, fraud_100, has_minimal_dependencies
+    pipeline_class_and_estimator, algorithm, fraud_100
 ):
-    if has_minimal_dependencies and algorithm == "lime":
-        pytest.skip("Skipping because lime is a non-core dependency")
-
     X, y = fraud_100
     pipeline_class, estimator = pipeline_class_and_estimator
 
@@ -1495,10 +1483,8 @@ def test_categories_aggregated_pca_dag(
     product(pipeline_test_cases, algorithms),
 )
 def test_categories_aggregated_but_not_those_that_are_dropped(
-    pipeline_class_and_estimator, algorithm, fraud_100, has_minimal_dependencies
+    pipeline_class_and_estimator, algorithm, fraud_100
 ):
-    if has_minimal_dependencies and algorithm == "lime":
-        pytest.skip("Skipping because lime is a non-core dependency")
     X, y = fraud_100
     pipeline_class, estimator = pipeline_class_and_estimator
 
@@ -1549,11 +1535,8 @@ def test_categories_aggregated_but_not_those_that_are_dropped(
     product(pipeline_test_cases, algorithms),
 )
 def test_categories_aggregated_when_some_are_dropped(
-    pipeline_class_and_estimator, algorithm, fraud_100, has_minimal_dependencies
+    pipeline_class_and_estimator, algorithm, fraud_100
 ):
-    if has_minimal_dependencies and algorithm == "lime":
-        pytest.skip("Skipping because lime is a non-core dependency")
-
     X, y = fraud_100
     pipeline_class, estimator = pipeline_class_and_estimator
 
@@ -1628,11 +1611,7 @@ def test_explain_predictions_stacked_ensemble(
     fraud_100,
     X_y_multi,
     X_y_regression,
-    has_minimal_dependencies,
 ):
-    if has_minimal_dependencies and algorithm == "lime":
-        pytest.skip("Skipping because lime is a non-core dependency")
-
     if is_binary(problem_type):
         X, y = fraud_100
         pipeline = BinaryClassificationPipeline(
@@ -1731,7 +1710,6 @@ def test_explain_predictions_stacked_ensemble(
         assert set(entry["explanations"][0]["feature_names"]) == exp_feature_names
 
 
-@pytest.mark.noncore_dependency
 @pytest.mark.parametrize(
     "estimator,algorithm",
     product(
@@ -1783,7 +1761,6 @@ def test_explain_predictions_oversampler(estimator, algorithm, fraud_100):
     assert report["feature_values"].isnull().sum() == 0
 
 
-@pytest.mark.noncore_dependency
 @pytest.mark.parametrize("problem_type", [ProblemTypes.MULTICLASS, ProblemTypes.BINARY])
 def test_explain_predictions_class_name_matches_class_name_in_y(
     problem_type, fraud_100
@@ -1896,11 +1873,7 @@ def test_explain_predictions_unknown(indices, X_y_binary):
 
 
 @pytest.mark.parametrize("algorithm", algorithms)
-def test_explain_predictions_url_email(
-    df_with_url_and_email, algorithm, has_minimal_dependencies
-):
-    if has_minimal_dependencies and algorithm == "lime":
-        pytest.skip("Skipping because lime is a non-core dependency")
+def test_explain_predictions_url_email(df_with_url_and_email, algorithm):
     X = df_with_url_and_email.ww.select(["url", "EmailAddress"])
     y = pd.Series([0, 1, 1, 0, 1])
 
@@ -1955,10 +1928,7 @@ def test_explain_predictions_postalcodes(
     algorithm,
     fraud_100,
     logistic_regression_binary_pipeline,
-    has_minimal_dependencies,
 ):
-    if has_minimal_dependencies and algorithm == "lime":
-        pytest.skip("Skipping because lime is a non-core dependency")
     X, y = fraud_100
     X.ww.set_types(
         logical_types={
@@ -2039,11 +2009,8 @@ def test_explain_predictions_postalcodes(
     product(pipeline_test_cases, algorithms),
 )
 def test_explain_predictions_report_shows_original_value_if_possible(
-    pipeline_class_and_estimator, algorithm, fraud_100, has_minimal_dependencies
+    pipeline_class_and_estimator, algorithm, fraud_100
 ):
-    if has_minimal_dependencies and algorithm == "lime":
-        pytest.skip("Skipping because lime is a non-core dependency")
-
     pipeline_class, estimator = pipeline_class_and_estimator
     X, y = fraud_100
     X.ww.set_types({"country": "NaturalLanguage"})
@@ -2105,10 +2072,8 @@ def test_explain_predictions_report_shows_original_value_if_possible(
 
 @pytest.mark.parametrize("algorithm", algorithms)
 def test_explain_predictions_best_worst_report_shows_original_value_if_possible(
-    algorithm, fraud_100, has_minimal_dependencies
+    algorithm, fraud_100
 ):
-    if has_minimal_dependencies and algorithm == "lime":
-        pytest.skip("Skipping because lime is a non-core dependency")
     X, y = fraud_100
     X.ww.set_types({"country": "NaturalLanguage"})
     component_graph = [
@@ -2173,11 +2138,7 @@ def test_explain_predictions_best_worst_report_shows_original_value_if_possible(
 
 
 @pytest.mark.parametrize("algorithm", algorithms)
-def test_explain_predictions_best_worst_json(
-    algorithm, fraud_100, has_minimal_dependencies
-):
-    if has_minimal_dependencies and algorithm == "lime":
-        pytest.skip("Skipping because lime is a non-core dependency")
+def test_explain_predictions_best_worst_json(algorithm, fraud_100):
     pipeline = BinaryClassificationPipeline(
         [
             "Natural Language Featurizer",
@@ -2211,7 +2172,6 @@ def test_explain_predictions_invalid_algorithm():
         )
 
 
-@pytest.mark.noncore_dependency
 def test_explain_predictions_lime_catboost(X_y_binary):
     pl = BinaryClassificationPipeline(
         {
