@@ -20,34 +20,53 @@ from evalml.model_understanding.metrics import (
 from evalml.utils import get_random_state
 
 
+@pytest.mark.parametrize("test_nullable", [True, False])
+@pytest.mark.parametrize("dtype", ["int", "bool"])
 @pytest.mark.parametrize("data_type", ["np", "pd", "ww"])
-def test_confusion_matrix(data_type, make_data_type):
-    y_true = np.array([2, 0, 2, 2, 0, 1, 1, 0, 2])
-    y_predicted = np.array([0, 0, 2, 2, 0, 2, 1, 1, 1])
-    y_true = make_data_type(data_type, y_true)
+def test_confusion_matrix(data_type, test_nullable, dtype, make_data_type):
+    if dtype == "int":
+        y_true = np.array([2, 0, 2, 2, 0, 1, 1, 0, 2])
+    elif dtype == "bool":
+        y_true = np.array([1, 0, 1, 1, 0, 1, 1, 0, 1]).astype(bool)
+
+    if dtype == "int":
+        y_predicted = np.array([0, 0, 2, 2, 0, 2, 1, 1, 1])
+    elif dtype == "bool":
+        y_predicted = np.array([0, 0, 1, 1, 0, 1, 1, 1, 1]).astype(bool)
+
+    y_true = make_data_type(data_type, y_true, nullable=test_nullable)
     y_predicted = make_data_type(data_type, y_predicted)
 
     conf_mat = confusion_matrix(y_true, y_predicted, normalize_method=None)
-    conf_mat_expected = np.array([[2, 1, 0], [0, 1, 1], [1, 1, 2]])
+    if dtype == "int":
+        conf_mat_expected = np.array([[2, 1, 0], [0, 1, 1], [1, 1, 2]])
+    elif dtype == "bool":
+        conf_mat_expected = np.array([[2, 1], [1, 5]])
     assert np.array_equal(conf_mat_expected, conf_mat.to_numpy())
     assert isinstance(conf_mat, pd.DataFrame)
 
     conf_mat = confusion_matrix(y_true, y_predicted, normalize_method="all")
     conf_mat_expected = conf_mat_expected / 9.0
-    assert np.array_equal(conf_mat_expected, conf_mat.to_numpy())
+    assert np.allclose(conf_mat_expected, conf_mat.to_numpy())
     assert isinstance(conf_mat, pd.DataFrame)
 
     conf_mat = confusion_matrix(y_true, y_predicted, normalize_method="true")
-    conf_mat_expected = np.array(
-        [[2 / 3.0, 1 / 3.0, 0], [0, 0.5, 0.5], [0.25, 0.25, 0.5]]
-    )
-    assert np.array_equal(conf_mat_expected, conf_mat.to_numpy())
+    if dtype == "int":
+        conf_mat_expected = np.array(
+            [[2 / 3.0, 1 / 3.0, 0], [0, 0.5, 0.5], [0.25, 0.25, 0.5]]
+        )
+    elif dtype == "bool":
+        conf_mat_expected = np.array([[0.666667, 0.33333], [0.166667, 0.83333]])
+    assert np.allclose(conf_mat_expected, conf_mat.to_numpy())
     assert isinstance(conf_mat, pd.DataFrame)
 
     conf_mat = confusion_matrix(y_true, y_predicted, normalize_method="pred")
-    conf_mat_expected = np.array(
-        [[2 / 3.0, 1 / 3.0, 0], [0, 1 / 3.0, 1 / 3.0], [1 / 3.0, 1 / 3.0, 2 / 3.0]]
-    )
+    if dtype == "int":
+        conf_mat_expected = np.array(
+            [[2 / 3.0, 1 / 3.0, 0], [0, 1 / 3.0, 1 / 3.0], [1 / 3.0, 1 / 3.0, 2 / 3.0]]
+        )
+    elif dtype == "bool":
+        conf_mat_expected = np.array([[0.666667, 0.166667], [0.333333, 0.83333]])
     assert np.allclose(conf_mat_expected, conf_mat.to_numpy(), equal_nan=True)
     assert isinstance(conf_mat, pd.DataFrame)
 
@@ -197,9 +216,9 @@ def test_precision_recall_curve(data_type, make_data_type):
     recall = precision_recall_curve_data.get("recall")
     thresholds = precision_recall_curve_data.get("thresholds")
 
-    precision_expected = np.array([0.66666667, 0.5, 1, 1])
-    recall_expected = np.array([1, 0.5, 0.5, 0])
-    thresholds_expected = np.array([0.35, 0.4, 0.8])
+    precision_expected = np.array([0.5, 0.66666667, 0.5, 1, 1])
+    recall_expected = np.array([1, 1, 0.5, 0.5, 0])
+    thresholds_expected = np.array([0.1, 0.35, 0.4, 0.8])
 
     np.testing.assert_almost_equal(precision_expected, precision, decimal=5)
     np.testing.assert_almost_equal(recall_expected, recall, decimal=5)
@@ -219,9 +238,9 @@ def test_precision_recall_curve_pos_label_idx():
     recall = precision_recall_curve_data.get("recall")
     thresholds = precision_recall_curve_data.get("thresholds")
 
-    precision_expected = np.array([0.66666667, 0.5, 1, 1])
-    recall_expected = np.array([1, 0.5, 0.5, 0])
-    thresholds_expected = np.array([0.35, 0.4, 0.8])
+    precision_expected = np.array([0.5, 0.66666667, 0.5, 1, 1])
+    recall_expected = np.array([1, 1, 0.5, 0.5, 0])
+    thresholds_expected = np.array([0.1, 0.35, 0.4, 0.8])
     np.testing.assert_almost_equal(precision_expected, precision, decimal=5)
     np.testing.assert_almost_equal(recall_expected, recall, decimal=5)
     np.testing.assert_almost_equal(thresholds_expected, thresholds, decimal=5)
@@ -247,7 +266,6 @@ def test_precision_recall_curve_pos_label_idx_error(make_data_type):
         precision_recall_curve(y_true, y_predict_proba, pos_label_idx=9001)
 
 
-@pytest.mark.noncore_dependency
 @pytest.mark.parametrize("data_type", ["np", "pd", "ww"])
 def test_graph_precision_recall_curve(X_y_binary, data_type, make_data_type, go):
 
@@ -275,7 +293,6 @@ def test_graph_precision_recall_curve(X_y_binary, data_type, make_data_type, go)
     )
 
 
-@pytest.mark.noncore_dependency
 def test_graph_precision_recall_curve_title_addition(X_y_binary, go):
 
     X, y_true = X_y_binary
@@ -291,11 +308,16 @@ def test_graph_precision_recall_curve_title_addition(X_y_binary, go):
     )
 
 
+@pytest.mark.parametrize("test_nullable", [True, False])
+@pytest.mark.parametrize("dtype", ["int", "bool"])
 @pytest.mark.parametrize("data_type", ["np", "pd", "ww"])
-def test_roc_curve_binary(data_type, make_data_type):
-    y_true = np.array([1, 1, 0, 0])
+def test_roc_curve_binary(test_nullable, dtype, data_type, make_data_type):
+    if dtype == "int":
+        y_true = np.array([1, 1, 0, 0])
+    elif dtype == "bool":
+        y_true = np.array([1, 1, 0, 0]).astype(bool)
     y_predict_proba = np.array([0.1, 0.4, 0.35, 0.8])
-    y_true = make_data_type(data_type, y_true)
+    y_true = make_data_type(data_type, y_true, nullable=test_nullable)
     y_predict_proba = make_data_type(data_type, y_predict_proba)
 
     roc_curve_data = roc_curve(y_true, y_predict_proba)[0]
@@ -380,7 +402,6 @@ def test_roc_curve_multiclass(data_type, make_data_type):
         assert isinstance(roc_curve_data[i]["thresholds"], np.ndarray)
 
 
-@pytest.mark.noncore_dependency
 @pytest.mark.parametrize("data_type", ["np", "pd", "ww"])
 def test_graph_roc_curve_binary(X_y_binary, data_type, make_data_type, go):
 
@@ -410,7 +431,6 @@ def test_graph_roc_curve_binary(X_y_binary, data_type, make_data_type, go):
     assert fig_dict["data"][1]["name"] == "Trivial Model (AUC 0.5)"
 
 
-@pytest.mark.noncore_dependency
 def test_graph_roc_curve_nans(go):
 
     one_val_y_zero = np.array([0])
@@ -431,7 +451,6 @@ def test_graph_roc_curve_nans(go):
     assert fig1 == fig2
 
 
-@pytest.mark.noncore_dependency
 def test_graph_roc_curve_multiclass(binarized_ys, go):
 
     y_true, y_tr, y_pred_proba = binarized_ys
@@ -462,7 +481,6 @@ def test_graph_roc_curve_multiclass(binarized_ys, go):
         graph_roc_curve(y_true, y_pred_proba, custom_class_names=["one", "two"])
 
 
-@pytest.mark.noncore_dependency
 def test_graph_roc_curve_multiclass_custom_class_names(binarized_ys, go):
 
     y_true, y_tr, y_pred_proba = binarized_ys
@@ -483,7 +501,6 @@ def test_graph_roc_curve_multiclass_custom_class_names(binarized_ys, go):
     assert fig_dict["data"][3]["name"] == "Trivial Model (AUC 0.5)"
 
 
-@pytest.mark.noncore_dependency
 def test_graph_roc_curve_title_addition(X_y_binary, go):
 
     X, y_true = X_y_binary
@@ -498,7 +515,6 @@ def test_graph_roc_curve_title_addition(X_y_binary, go):
     )
 
 
-@pytest.mark.noncore_dependency
 @pytest.mark.parametrize("data_type", ["np", "pd", "ww"])
 def test_graph_confusion_matrix_default(X_y_binary, data_type, make_data_type, go):
 
@@ -537,7 +553,6 @@ def test_graph_confusion_matrix_default(X_y_binary, data_type, make_data_type, g
         assert "text" in annotations[i]
 
 
-@pytest.mark.noncore_dependency
 def test_graph_confusion_matrix_norm_disabled(X_y_binary, go):
 
     X, y_true = X_y_binary
@@ -565,7 +580,6 @@ def test_graph_confusion_matrix_norm_disabled(X_y_binary, go):
     )
 
 
-@pytest.mark.noncore_dependency
 def test_graph_confusion_matrix_title_addition(X_y_binary, go):
 
     X, y_true = X_y_binary
@@ -580,7 +594,6 @@ def test_graph_confusion_matrix_title_addition(X_y_binary, go):
     )
 
 
-@pytest.mark.noncore_dependency
 @patch("evalml.model_understanding.metrics.jupyter_check")
 @patch("evalml.model_understanding.metrics.import_or_raise")
 def test_jupyter_graph_check(
