@@ -17,8 +17,10 @@ def test_binary_init():
         "Imputer": {
             "categorical_impute_strategy": "most_frequent",
             "numeric_impute_strategy": "mean",
+            "boolean_impute_strategy": "most_frequent",
             "categorical_fill_value": None,
             "numeric_fill_value": None,
+            "boolean_fill_value": None,
         },
         "One Hot Encoder": {
             "top_n": 10,
@@ -44,8 +46,10 @@ def test_binary_init():
         "Imputer": {
             "categorical_impute_strategy": "most_frequent",
             "numeric_impute_strategy": "mean",
+            "boolean_impute_strategy": "most_frequent",
             "categorical_fill_value": None,
             "numeric_fill_value": None,
+            "boolean_fill_value": None,
         },
         "One Hot Encoder": {
             "top_n": 20,
