@@ -11,6 +11,8 @@ def test_multiclass_init():
             "numeric_impute_strategy": "mean",
             "categorical_fill_value": None,
             "numeric_fill_value": None,
+            "boolean_impute_strategy": "most_frequent",
+            "boolean_fill_value": None,
         },
         "One Hot Encoder": {
             "top_n": 10,
@@ -36,8 +38,10 @@ def test_multiclass_init():
         "Imputer": {
             "categorical_impute_strategy": "most_frequent",
             "numeric_impute_strategy": "mean",
+            "boolean_impute_strategy": "most_frequent",
             "categorical_fill_value": None,
             "numeric_fill_value": None,
+            "boolean_fill_value": None,
         },
         "One Hot Encoder": {
             "top_n": 20,
