@@ -235,13 +235,7 @@ def test_make_pipeline_known_in_advance(
     problem_type,
     sampler,
     get_test_data_from_configuration,
-    has_minimal_dependencies,
 ):
-    if has_minimal_dependencies and sampler == "Oversampler":
-        pytest.skip(
-            "Skipping because oversampler test cases require imblearn (a noncore dependency)"
-        )
-
     X, y = get_test_data_from_configuration(
         "ww",
         problem_type,
@@ -482,12 +476,7 @@ def test_make_pipeline_samplers(
     X_y_binary,
     X_y_multi,
     X_y_regression,
-    has_minimal_dependencies,
 ):
-    if has_minimal_dependencies and sampler == "Oversampler":
-        pytest.skip(
-            "Skipping because oversampler test cases require imblearn (a noncore dependency)"
-        )
     if problem_type == "binary":
         X, y = X_y_binary
     elif problem_type == "multiclass":
@@ -513,33 +502,19 @@ def test_make_pipeline_samplers(
                 )
 
 
-def test_get_estimators(has_minimal_dependencies):
-    if has_minimal_dependencies:
-        assert len(get_estimators(problem_type=ProblemTypes.BINARY)) == 5
-        assert (
-            len(
-                get_estimators(
-                    problem_type=ProblemTypes.BINARY,
-                    model_families=[ModelFamily.LINEAR_MODEL],
-                )
+def test_get_estimators():
+    assert len(get_estimators(problem_type=ProblemTypes.BINARY)) == 8
+    assert (
+        len(
+            get_estimators(
+                problem_type=ProblemTypes.BINARY,
+                model_families=[ModelFamily.LINEAR_MODEL],
             )
-            == 2
         )
-        assert len(get_estimators(problem_type=ProblemTypes.MULTICLASS)) == 5
-        assert len(get_estimators(problem_type=ProblemTypes.REGRESSION)) == 4
-    else:
-        assert len(get_estimators(problem_type=ProblemTypes.BINARY)) == 8
-        assert (
-            len(
-                get_estimators(
-                    problem_type=ProblemTypes.BINARY,
-                    model_families=[ModelFamily.LINEAR_MODEL],
-                )
-            )
-            == 2
-        )
-        assert len(get_estimators(problem_type=ProblemTypes.MULTICLASS)) == 8
-        assert len(get_estimators(problem_type=ProblemTypes.REGRESSION)) == 7
+        == 2
+    )
+    assert len(get_estimators(problem_type=ProblemTypes.MULTICLASS)) == 8
+    assert len(get_estimators(problem_type=ProblemTypes.REGRESSION)) == 7
 
     assert len(get_estimators(problem_type=ProblemTypes.BINARY, model_families=[])) == 0
     assert (
@@ -609,7 +584,7 @@ def test_generate_code_pipeline_json_with_objects():
         generated_pipeline_code
         == "from evalml.pipelines.binary_classification_pipeline import BinaryClassificationPipeline\n"
         "pipeline = BinaryClassificationPipeline(component_graph={'Imputer': ['Imputer', 'X', 'y'], 'My Custom Estimator': [CustomEstimator, 'Imputer.x', 'y']}, "
-        "parameters={'Imputer':{'categorical_impute_strategy': 'most_frequent', 'numeric_impute_strategy': 'mean', 'categorical_fill_value': None, 'numeric_fill_value': None}, "
+        "parameters={'Imputer':{'categorical_impute_strategy': 'most_frequent', 'numeric_impute_strategy': 'mean', 'boolean_impute_strategy': 'most_frequent', 'categorical_fill_value': None, 'numeric_fill_value': None, 'boolean_fill_value': None}, "
         "'My Custom Estimator':{'random_arg': False, 'numpy_arg': array([0])}}, custom_name='Mock Binary Pipeline with Transformer', random_seed=0)"
     )
 
@@ -623,8 +598,8 @@ def test_generate_code_pipeline_json_with_objects():
         generated_pipeline_code
         == "from evalml.pipelines.binary_classification_pipeline import BinaryClassificationPipeline\n"
         "pipeline = BinaryClassificationPipeline(component_graph={'Imputer': ['Imputer', 'X', 'y'], 'My Custom Estimator': [CustomEstimator, 'Imputer.x', 'y']}, "
-        "parameters={'Imputer':{'categorical_impute_strategy': 'most_frequent', 'numeric_impute_strategy': 'mean', 'categorical_fill_value': None, 'numeric_fill_value': None}, "
-        "'My Custom Estimator':{'random_arg': Imputer(categorical_impute_strategy='most_frequent', numeric_impute_strategy='mean', categorical_fill_value=None, numeric_fill_value=None), 'numpy_arg': []}}, "
+        "parameters={'Imputer':{'categorical_impute_strategy': 'most_frequent', 'numeric_impute_strategy': 'mean', 'boolean_impute_strategy': 'most_frequent', 'categorical_fill_value': None, 'numeric_fill_value': None, 'boolean_fill_value': None}, "
+        "'My Custom Estimator':{'random_arg': Imputer(categorical_impute_strategy='most_frequent', numeric_impute_strategy='mean', boolean_impute_strategy='most_frequent', categorical_fill_value=None, numeric_fill_value=None, boolean_fill_value=None), 'numpy_arg': []}}, "
         "custom_name='Mock Binary Pipeline with Transformer', random_seed=0)"
     )
 
@@ -637,7 +612,7 @@ def test_generate_code_pipeline():
     expected_code = (
         "from evalml.pipelines.binary_classification_pipeline import BinaryClassificationPipeline\n"
         "pipeline = BinaryClassificationPipeline(component_graph={'Imputer': ['Imputer', 'X', 'y'], 'Random Forest Classifier': ['Random Forest Classifier', 'Imputer.x', 'y']}, "
-        "parameters={'Imputer':{'categorical_impute_strategy': 'most_frequent', 'numeric_impute_strategy': 'mean', 'categorical_fill_value': None, 'numeric_fill_value': None}, "
+        "parameters={'Imputer':{'categorical_impute_strategy': 'most_frequent', 'numeric_impute_strategy': 'mean', 'boolean_impute_strategy': 'most_frequent', 'categorical_fill_value': None, 'numeric_fill_value': None, 'boolean_fill_value': None}, "
         "'Random Forest Classifier':{'n_estimators': 100, 'max_depth': 6, 'n_jobs': -1}}, random_seed=0)"
     )
     pipeline = generate_pipeline_code(binary_pipeline)
@@ -648,7 +623,7 @@ def test_generate_code_pipeline():
     )
     expected_code = (
         "from evalml.pipelines.regression_pipeline import RegressionPipeline\n"
-        "pipeline = RegressionPipeline(component_graph={'Imputer': ['Imputer', 'X', 'y'], 'Random Forest Regressor': ['Random Forest Regressor', 'Imputer.x', 'y']}, parameters={'Imputer':{'categorical_impute_strategy': 'most_frequent', 'numeric_impute_strategy': 'mean', 'categorical_fill_value': None, 'numeric_fill_value': None}, "
+        "pipeline = RegressionPipeline(component_graph={'Imputer': ['Imputer', 'X', 'y'], 'Random Forest Regressor': ['Random Forest Regressor', 'Imputer.x', 'y']}, parameters={'Imputer':{'categorical_impute_strategy': 'most_frequent', 'numeric_impute_strategy': 'mean', 'boolean_impute_strategy': 'most_frequent', 'categorical_fill_value': None, 'numeric_fill_value': None, 'boolean_fill_value': None}, "
         "'Random Forest Regressor':{'n_estimators': 100, 'max_depth': 6, 'n_jobs': -1}}, custom_name='Mock Regression Pipeline', random_seed=0)"
     )
     pipeline = generate_pipeline_code(regression_pipeline)
@@ -665,7 +640,7 @@ def test_generate_code_pipeline():
     expected_code_params = (
         "from evalml.pipelines.regression_pipeline import RegressionPipeline\n"
         "pipeline = RegressionPipeline(component_graph={'Imputer': ['Imputer', 'X', 'y'], 'Random Forest Regressor': ['Random Forest Regressor', 'Imputer.x', 'y']}, "
-        "parameters={'Imputer':{'categorical_impute_strategy': 'most_frequent', 'numeric_impute_strategy': 'most_frequent', 'categorical_fill_value': None, 'numeric_fill_value': None}, "
+        "parameters={'Imputer':{'categorical_impute_strategy': 'most_frequent', 'numeric_impute_strategy': 'most_frequent', 'boolean_impute_strategy': 'most_frequent', 'categorical_fill_value': None, 'numeric_fill_value': None, 'boolean_fill_value': None}, "
         "'Random Forest Regressor':{'n_estimators': 50, 'max_depth': 6, 'n_jobs': -1}}, custom_name='Mock Regression Pipeline', random_seed=0)"
     )
     pipeline = generate_pipeline_code(regression_pipeline_with_params)
@@ -699,7 +674,7 @@ def test_generate_code_nonlinear_pipeline():
         "'Random Forest': ['Random Forest Classifier', 'OneHot_RandomForest.x', 'y'], "
         "'Elastic Net': ['Elastic Net Classifier', 'OneHot_ElasticNet.x', 'y'], "
         "'Logistic Regression Classifier': ['Logistic Regression Classifier', 'Random Forest.x', 'Elastic Net.x', 'y']}, "
-        "parameters={'Imputer':{'categorical_impute_strategy': 'most_frequent', 'numeric_impute_strategy': 'mean', 'categorical_fill_value': None, 'numeric_fill_value': None}, "
+        "parameters={'Imputer':{'categorical_impute_strategy': 'most_frequent', 'numeric_impute_strategy': 'mean', 'boolean_impute_strategy': 'most_frequent', 'categorical_fill_value': None, 'numeric_fill_value': None, 'boolean_fill_value': None}, "
         "'OneHot_RandomForest':{'top_n': 10, 'features_to_encode': None, 'categories': None, 'drop': 'if_binary', 'handle_unknown': 'ignore', 'handle_missing': 'error'}, "
         "'OneHot_ElasticNet':{'top_n': 10, 'features_to_encode': None, 'categories': None, 'drop': 'if_binary', 'handle_unknown': 'ignore', 'handle_missing': 'error'}, "
         "'Random Forest':{'n_estimators': 100, 'max_depth': 6, 'n_jobs': -1}, "
