@@ -1060,6 +1060,90 @@ def test_binary_predict_pipeline_objective_mismatch(
         binary_pipeline.predict(X[30:32], "precision micro", X[:30], y[:30])
 
 
+@pytest.fixture
+def time_series_default_pipeline_classification_parameters():
+    parameters = {
+        "Logistic Regression Classifier": {"n_jobs": 1},
+        "pipeline": {
+            "gap": 0,
+            "max_delay": 0,
+            "time_index": "date",
+            "forecast_horizon": 10,
+        },
+        "Time Series Featurizer": {
+            "gap": 0,
+            "max_delay": 0,
+            "time_index": "date",
+            "forecast_horizon": 10,
+        },
+    }
+    return parameters
+
+
+@pytest.mark.parametrize(
+    "problem_type",
+    [
+        ProblemTypes.TIME_SERIES_BINARY,
+        ProblemTypes.TIME_SERIES_MULTICLASS,
+        ProblemTypes.TIME_SERIES_REGRESSION,
+    ],
+)
+def test_time_series_pipeline_predict_none_parameter_valueerror(
+    problem_type,
+    ts_data_binary,
+    ts_data_multi,
+    ts_data,
+    time_series_binary_classification_pipeline_class,
+    time_series_multiclass_classification_pipeline_class,
+    time_series_regression_pipeline_class,
+    time_series_default_pipeline_classification_parameters,
+):
+    if problem_type == ProblemTypes.TIME_SERIES_BINARY:
+        X, y = ts_data_binary
+        clf = time_series_binary_classification_pipeline_class(
+            parameters=time_series_default_pipeline_classification_parameters
+        )
+
+    elif problem_type == ProblemTypes.TIME_SERIES_MULTICLASS:
+        X, y = ts_data_multi
+        clf = time_series_multiclass_classification_pipeline_class(
+            parameters=time_series_default_pipeline_classification_parameters
+        )
+    else:
+        X, y = ts_data
+        clf = time_series_regression_pipeline_class(
+            parameters={
+                "Random Forest Regressor": {"n_jobs": 1},
+                "pipeline": {
+                    "gap": 0,
+                    "max_delay": 0,
+                    "time_index": "date",
+                    "forecast_horizon": 10,
+                },
+                "Time Series Featurizer": {
+                    "gap": 0,
+                    "max_delay": 0,
+                    "time_index": "date",
+                    "forecast_horizon": 10,
+                },
+            }
+        )
+
+    X, y = pd.DataFrame(X), pd.Series(y)
+    X_train, y_train = X.iloc[:21], y.iloc[:21]
+    clf.fit(X_train, y_train)
+    with pytest.raises(
+        ValueError,
+        match="Make sure to include an input for y_train when calling time series' predict",
+    ):
+        clf.predict(X=X, X_train=X_train)
+    with pytest.raises(
+        ValueError,
+        match="Make sure to include an input for X_train when calling time series' predict",
+    ):
+        clf.predict(X=X)
+
+
 @pytest.mark.parametrize(
     "problem_type",
     [
@@ -1076,45 +1160,18 @@ def test_time_series_pipeline_not_fitted_error(
     time_series_binary_classification_pipeline_class,
     time_series_multiclass_classification_pipeline_class,
     time_series_regression_pipeline_class,
+    time_series_default_pipeline_classification_parameters,
 ):
     if problem_type == ProblemTypes.TIME_SERIES_BINARY:
         X, y = ts_data_binary
         clf = time_series_binary_classification_pipeline_class(
-            parameters={
-                "Logistic Regression Classifier": {"n_jobs": 1},
-                "pipeline": {
-                    "gap": 0,
-                    "max_delay": 0,
-                    "time_index": "date",
-                    "forecast_horizon": 10,
-                },
-                "Time Series Featurizer": {
-                    "gap": 0,
-                    "max_delay": 0,
-                    "time_index": "date",
-                    "forecast_horizon": 10,
-                },
-            }
+            parameters=time_series_default_pipeline_classification_parameters
         )
 
     elif problem_type == ProblemTypes.TIME_SERIES_MULTICLASS:
         X, y = ts_data_multi
         clf = time_series_multiclass_classification_pipeline_class(
-            parameters={
-                "Logistic Regression Classifier": {"n_jobs": 1},
-                "pipeline": {
-                    "gap": 0,
-                    "max_delay": 0,
-                    "time_index": "date",
-                    "forecast_horizon": 10,
-                },
-                "Time Series Featurizer": {
-                    "gap": 0,
-                    "max_delay": 0,
-                    "time_index": "date",
-                    "forecast_horizon": 10,
-                },
-            }
+            parameters=time_series_default_pipeline_classification_parameters
         )
     else:
         X, y = ts_data
@@ -1182,7 +1239,10 @@ def test_time_series_pipeline_not_fitted_error(
 
 
 def test_ts_binary_pipeline_target_thresholding(
-    make_data_type, time_series_binary_classification_pipeline_class, ts_data_binary
+    make_data_type,
+    time_series_binary_classification_pipeline_class,
+    ts_data_binary,
+    time_series_default_pipeline_classification_parameters,
 ):
     X, y = ts_data_binary
     X = make_data_type("ww", X)
@@ -1190,21 +1250,7 @@ def test_ts_binary_pipeline_target_thresholding(
     objective = get_objective("F1", return_instance=True)
 
     binary_pipeline = time_series_binary_classification_pipeline_class(
-        parameters={
-            "Logistic Regression Classifier": {"n_jobs": 1},
-            "pipeline": {
-                "gap": 0,
-                "max_delay": 0,
-                "time_index": "date",
-                "forecast_horizon": 10,
-            },
-            "Time Series Featurizer": {
-                "time_index": "date",
-                "gap": 0,
-                "max_delay": 0,
-                "forecast_horizon": 10,
-            },
-        }
+        parameters=time_series_default_pipeline_classification_parameters
     )
     X_train, y_train = X.ww.iloc[:21], y.ww.iloc[:21]
     X_holdout, y_holdout = X.ww.iloc[21:], y.ww.iloc[21:]
@@ -1314,7 +1360,6 @@ def test_time_series_pipeline_fit_with_transformed_target(
 
 
 @pytest.mark.skip_if_39
-@pytest.mark.noncore_dependency
 def test_time_series_pipeline_with_detrender(ts_data):
     X, y = ts_data
     component_graph = {
