@@ -1,5 +1,4 @@
 import os
-import pathlib
 from unittest.mock import patch
 
 import pytest
@@ -8,6 +7,7 @@ from click.testing import CliRunner
 
 from evalml.__main__ import cli
 from evalml.utils.cli_utils import (
+    get_evalml_pip_requirements,
     get_evalml_root,
     get_installed_packages,
     get_sys_info,
@@ -22,13 +22,11 @@ def current_dir():
     return os.path.dirname(os.path.abspath(__file__))
 
 
-def get_core_requirements(current_dir):
-    reqs_path = os.path.join(
-        current_dir, pathlib.Path("..", "..", "..", "core-requirements.txt")
-    )
-    lines = open(reqs_path, "r").readlines()
-    lines = [line for line in lines if "-r " not in line]
-    reqs = requirements.parse("".join(lines))
+def get_requirements(current_dir):
+    evalml_path = os.path.abspath(os.path.join(current_dir, "..", "..", ".."))
+    full_requirements = get_evalml_pip_requirements(evalml_path)
+
+    reqs = requirements.parse("".join(full_requirements))
     reqs_names = [req.name for req in reqs]
     return reqs_names
 
@@ -66,11 +64,11 @@ def test_print_sys_info(caplog):
 
 
 def test_print_deps_info(caplog, current_dir):
-    core_requirements = get_core_requirements(current_dir)
+    requirements = get_requirements(current_dir)
     print_deps()
     out = caplog.text
     assert "INSTALLED VERSIONS" in out
-    for requirement in core_requirements:
+    for requirement in requirements:
         assert requirement in out
 
 
@@ -101,8 +99,8 @@ def test_sys_info_error(mock_uname):
 
 def test_installed_packages(current_dir):
     installed_packages = get_installed_packages()
-    core_requirements = get_core_requirements(current_dir)
-    assert set(core_requirements).issubset(installed_packages.keys())
+    requirements = get_requirements(current_dir)
+    assert set(requirements).issubset(installed_packages.keys())
 
 
 def test_get_evalml_root(current_dir):
