@@ -89,6 +89,36 @@ class Tuner(ABC):
             pipeline_parameters[component_name][parameter_name] = parameter_value
         return pipeline_parameters
 
+    def get_starting_parameters(self, hyperparameter_ranges, random_seed=0):
+        """Gets the starting parameters given the pipeline hyperparameter range.
+
+        Arguments:
+            hyperparameter_ranges (dict): The custom hyperparameter ranges passed in during search. Used to determine the starting parameters.
+            random_seed (int): The random seed to use. Defaults to 0.
+
+        Returns:
+            dict: The starting parameters, randomly chosen, to initialize a pipeline with.
+        """
+        starting_parameters = {}
+        for name, param_dict in hyperparameter_ranges.items():
+            component_parameters = {}
+            for param_name, value in param_dict.items():
+                if isinstance(value, (Integer, Real)):
+                    # get a random value in the space
+                    component_parameters[param_name] = value.rvs(
+                        random_state=random_seed
+                    )[0]
+                elif isinstance(value, Categorical):
+                    # Categorical
+                    component_parameters[param_name] = value.rvs(
+                        random_state=random_seed
+                    )
+                elif isinstance(value, (list, tuple)):
+                    # list value from our internal hyperparameter_ranges
+                    component_parameters[param_name] = value[0]
+            starting_parameters[name] = component_parameters
+        return starting_parameters
+
     @abstractmethod
     def add(self, pipeline_parameters, score):
         """Register a set of hyperparameters with the score obtained from training a pipeline with those hyperparameters.
